@@ -1,7 +1,6 @@
 `plot.HTSCluster` <-
-function (x, data, file.name = FALSE, 
-graphs = c("map", "map.bycluster", "lambda"), 
-lambda.plot = c("bar"), ...) 
+function (x,file.name = FALSE, 
+graphs = c("map", "map.bycluster", "lambda"), data=NA, ...) 
 {
 	
     	if (class(x) != "HTSCluster") {
@@ -15,8 +14,6 @@ lambda.plot = c("bar"), ...)
 #	}
 
 	conds <- x$conds;
-	n <- nrow(data)
-	data.w <- data/rowSums(data)
 	BIC <- x$BIC
 	ICL <- x$ICL
 	labels <- x$labels
@@ -26,10 +23,11 @@ lambda.plot = c("bar"), ...)
 	g <- length(pi)
 
 	## Plot dimensions
-	if(g > 36) {
-		stop("Visualization of individual clusters not yet possible for a 
-			large number of clusters (> 36).")
-	}
+#	if(g > 36) {
+#		stop("Visualization of individual clusters not yet possible for a 
+#			large number of clusters (> 36).")
+#	}
+
 	if(g == 1) plot.dim <- c(1,1)
 	if(g == 2) plot.dim <- c(1,2)
 	if(g == 3 | g == 4) plot.dim <- c(2,2)
@@ -85,7 +83,14 @@ lambda.plot = c("bar"), ...)
 
 	## Weighted histograms
 	if("weighted.histograms" %in% graphs) {
+	if(is.na(data) == TRUE) stop("Must provide original data for weighted histograms to be plotted.")
+	n <- nrow(data)
+	data.w <- data/rowSums(data)
 	if(file.name == FALSE) par(ask = TRUE);
+	if(g > 36) {
+		stop("Weighted histograms not yet possible for a 
+			large number of clusters (> 36).")
+	}
 	for(var in 1:dim(data)[2]) {
 		par(mfrow = plot.dim, mar = c(4,4,2,2), oma = c(1,1,2,0)) 
 		for(clus in 1:g) {
@@ -147,69 +152,75 @@ lambda.plot = c("bar"), ...)
 			", by cluster", sep = "")), cex = 1.25,
 			font = 2)
 	}
-	if(length(unique(conds)) == 2) {
-		par(oma = c(0,1,0,0), mfrow = c(1,1))
-		bar <- barplot(unlist(lambda[1,]), ylim = c(-(max(lambda)+.25), max(lambda)+.25), 
-			col = "lightgrey",
-			width = unlist(pi), names.arg = 1:g, xlab = "Cluster", 
-			cex.lab = 1.25, cex.names = 1.25, yaxt = "n", main = "", cex.main = 1.5)
-		axis(side = 2, at = seq(from = -2.5, to = 2.5, by = 0.5), 
-			labels = c(seq(from = 2.5, to = 0, by = -0.5), seq(from = 0.5, to = 2.5, 
-			by = 0.5)))
-		barplot(unlist(-lambda[2,]), add = T, col = "darkgrey", width = unlist(pi), 
-			names.arg = 1:g, cex.names = 1.25, yaxt = "n")
-		mtext(side = 2, line = 3, at = 1, expression(hat(lambda)[1*k]), cex = 1.5)
-		mtext(side = 2, line = 3, at = -1, expression(hat(lambda)[2*k]), cex = 1.5)
-		abline(h = 0, lwd = 2)
-		abline(h = c(-1,1), lty = 2)
-		pi.lab <- paste(round(unlist(pi)*100,1), "%", sep = "")
-		text(bar, unlist(lambda[1,]) + .15, pi.lab, xpd = TRUE, col = "blue")
-		mtext(side = 3, outer = F, line = 0,
-			expression(paste("Relative values of ", (lambda)[k], 
-			", by cluster", sep = "")), cex = 1.25,
-			font = 2)
-	}
-	if(length(unique(conds)) > 2 & lambda.plot == "stars") {
-
-		par(oma = c(3*dim(lambda)[1],0,0,0), mfrow = c(1,1))
-		lambda.scale <- t(lambda) / rowSums(t(lambda))
-		rownames(lambda.scale) <- paste(rownames(lambda.scale),
-			" (", round(pi*100,2), "%", ")", sep = "")
-		st <- stars(lambda.scale, draw.segments = TRUE, scale = FALSE,
-			mar = c(0,0,3,0), full = FALSE,
-			col.segments = 1:dim(lambda)[1], 
-			main = expression(paste("Relative values of ", (lambda)[k], 
-			", by cluster", sep = "")), cex = 1.25, len = pi/max(pi))
-#		text(st[,1], st[,2]+.55, paste("(", round(pi*100,2), "%", ")", sep = ""))
-		par(xpd=NA)
-		legend(mean(par("usr")[1:2]-.5),mean(par("usr")[3]-.1), col = 1:dim(lambda)[1], 
-			paste("Condition", unique(conds)), pch = 19)
-
-	}
-	if(length(unique(conds)) > 2 & lambda.plot == "pie") {
-		df <- data.frame(x = as.vector(lambda), lambda=rep(rownames(lambda),g),
-                 cluster = rep( paste("Cluster ", 1:g, "\npi = ", round(pi,2),  
-			"\n(", table(labels), " obs)", sep = ""),
-                   	each = nrow(lambda)))
-		df$cluster <- factor(df$cluster, 
-			levels = rep( paste("Cluster ", 1:g, "\npi = ", round(pi,2), 
-			"\n(", table(labels), " obs)", sep = "")))
-		levels(df$lambda) <- rownames(lambda)
-		gg <- ggplot(df, aes(x = lambda, fill = factor(lambda))) + 
-			geom_bar(aes(weight=x)) + theme(legend.position="none") +
-  			scale_fill_manual(name = "Group", values = rev(brewer.pal(nrow(lambda), "Set3"))) + 
-			facet_wrap(~cluster) + coord_polar() +
-  			labs(x = "", y = "") + theme_bw() + theme(axis.text.x = element_blank())
-		print(gg)
-	}
-	if(length(unique(conds)) > 2 & lambda.plot == "bar") {
+#	if(length(unique(conds)) == 2) {
+#		par(oma = c(0,1,0,0), mfrow = c(1,1))
+#		bar <- barplot(unlist(lambda[1,]), ylim = c(-(max(lambda)+.25), max(lambda)+.25), 
+#			col = "lightgrey",
+#			width = unlist(pi), names.arg = 1:g, xlab = "Cluster", 
+#			cex.lab = 1.25, cex.names = 1.25, yaxt = "n", main = "", cex.main = 1.5)
+#		axis(side = 2, at = seq(from = -2.5, to = 2.5, by = 0.5), 
+#			labels = c(seq(from = 2.5, to = 0, by = -0.5), seq(from = 0.5, to = 2.5, 
+#			by = 0.5)))
+#		barplot(unlist(-lambda[2,]), add = T, col = "darkgrey", width = unlist(pi), 
+#			names.arg = 1:g, cex.names = 1.25, yaxt = "n")
+#		mtext(side = 2, line = 3, at = 1, expression(hat(lambda)[1*k]), cex = 1.5)
+#		mtext(side = 2, line = 3, at = -1, expression(hat(lambda)[2*k]), cex = 1.5)
+#		abline(h = 0, lwd = 2)
+#		abline(h = c(-1,1), lty = 2)
+#		pi.lab <- paste(round(unlist(pi)*100,1), "%", sep = "")
+#		text(bar, unlist(lambda[1,]) + .15, pi.lab, xpd = TRUE, col = "blue")
+#		mtext(side = 3, outer = F, line = 0,
+#			expression(paste("Relative values of ", (lambda)[k], 
+#			", by cluster", sep = "")), cex = 1.25,
+#			font = 2)
+#	}
+#	if(length(unique(conds)) > 2 & lambda.plot == "stars") {
+#
+#		par(oma = c(3*dim(lambda)[1],0,0,0), mfrow = c(1,1))
+#		lambda.scale <- t(lambda) / rowSums(t(lambda))
+#		rownames(lambda.scale) <- paste(rownames(lambda.scale),
+#			" (", round(pi*100,2), "%", ")", sep = "")
+#		st <- stars(lambda.scale, draw.segments = TRUE, scale = FALSE,
+#			mar = c(0,0,3,0), full = FALSE,
+#			col.segments = 1:dim(lambda)[1], 
+#			main = expression(paste("Relative values of ", (lambda)[k], 
+#			", by cluster", sep = "")), cex = 1.25, len = pi/max(pi))
+##		text(st[,1], st[,2]+.55, paste("(", round(pi*100,2), "%", ")", sep = ""))
+#		par(xpd=NA)
+#		legend(mean(par("usr")[1:2]-.5),mean(par("usr")[3]-.1), col = 1:dim(lambda)[1], 
+#			paste("Condition", unique(conds)), pch = 19)
+#
+#	}
+#	if(length(unique(conds)) > 2 & lambda.plot == "pie") {
+#		df <- data.frame(x = as.vector(lambda), lambda=rep(rownames(lambda),g),
+#                 cluster = rep( paste("Cluster ", 1:g, "\npi = ", round(pi,2),  
+#			"\n(", table(labels), " obs)", sep = ""),
+#                   	each = nrow(lambda)))
+#		df$cluster <- factor(df$cluster, 
+#			levels = rep( paste("Cluster ", 1:g, "\npi = ", round(pi,2), 
+#			"\n(", table(labels), " obs)", sep = "")))
+#		levels(df$lambda) <- rownames(lambda)
+#		gg <- ggplot(df, aes(x = lambda, fill = factor(lambda))) + 
+#			geom_bar(aes(weight=x)) + theme(legend.position="none") +
+# 			scale_fill_manual(name = "Group", values = rev(brewer.pal(nrow(lambda), "Set3"))) + 
+#			facet_wrap(~cluster) + coord_polar() +
+#  			labs(x = "", y = "") + theme_bw() + theme(axis.text.x = element_blank())
+#		print(gg)
+#	}
+	if(length(unique(conds)) >= 2) {
 		s <- x$s
 		ss <- rep(NA, length(unique(conds))) 
 		for(c in 1:length(unique(conds))) {
 			ss[c] <- sum(s[which(conds == unique(conds)[c])])
 		}
-		barplot(lambda*ss, beside=FALSE, col=brewer.pal(length(unique(conds)), "Accent"), width = pi, legend.text = rownames(lambda),
-        		args.legend = list(x=1.2, y=-0.1, horiz=TRUE))
+		b <- barplot(lambda*ss, beside=FALSE, col=1:length(unique(conds)), width = pi, legend.text = rownames(lambda),
+        		args.legend = list(y=-0.1, horiz=TRUE, bty="n"),
+				names.arg=rep("", ncol(lambda)), space=0)
+		mtext(side=2, outer=F, expression(paste(lambda[jk], s[j.])), 
+			line=2)
+		mtext(side=1, outer=F, "Cluster", line=2.5)
+		mtext(side=1, at=b, line = 0, 1:ncol(lambda), cex = 0.75)
+		if(length(unique(conds)) == 2) abline(h=0.5, lty=2, col="grey")
 	}
       }
 	if(file.name != FALSE)  dev.off();
